sqlite

package module
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 6, 2018 License: BSD-3-Clause Imports: 16 Imported by: 0

README

sqlite

Package sqlite is an in-process implementation of a self-contained, serverless, zero-configuration, transactional SQL database engine. (Work In Progress)

Installation

$ go get modernc.org/sqlite

Documentation: godoc.org/modernc.org/sqlite

Documentation

Overview

Package sqlite is an in-process implementation of a self-contained, serverless, zero-configuration, transactional SQL database engine. (Work In Progress)

Changelog

2017-06-10 Windows/Intel no more uses the VM (thanks Steffen Butzer).

2017-06-05 Linux/Intel no more uses the VM (cznic/virtual).

Connecting to a database

To access a Sqlite database do something like

import (
	"database/sql"

	_ "modernc.org/sqlite"
)

...

db, err := sql.Open("sqlite", dsnURI)

...

Do not use in production

This is an experimental, pre-alpha, technology preview package.

The alpha release is due when the C runtime support of SQLite in cznic/crt will be complete.

Supported platforms and architectures

See http://modernc.org/ccir. To add a newly supported os/arch combination to this package try running 'go generate'.

Sqlite documentation

See https://sqlite.org/docs.html

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Driver

type Driver struct {
	sync.Mutex
}

Driver implements database/sql/driver.Driver.

func (*Driver) Open

func (s *Driver) Open(name string) (c driver.Conn, err error)

Open returns a new connection to the database. The name is a string in a driver-specific format.

Open may return a cached connection (one previously closed), but doing so is unnecessary; the sql package maintains a pool of idle connections for efficient re-use.

The returned connection is only used by one goroutine at a time.

Directories

Path Synopsis
internal
bin
Package sqlite is an in-process implementation of a self-contained, serverless, zero-configuration, transactional SQL database engine.
Package sqlite is an in-process implementation of a self-contained, serverless, zero-configuration, transactional SQL database engine.
mptest command
mptest
mptest
threadtest1 command
threadtest1
threadtest1
threadtest2 command
threadtest2
threadtest2
threadtest3 command
/* ** The "Set Error Line" macro.
/* ** The "Set Error Line" macro.
threadtest4 command
threadtest4
threadtest4
v2
cc module
cc3 module
cc4 module
ccgo3 module
ccgo4 module
ccir module
ccorpus2 module
ebnf module
ebnfutil module
fileutil module
gc2 module
gc3 module
goabi0 module
httpfs module
ir module
lex module
lexer module
libc module
libtcl8.6 module
libz module
mathutil module
memory module
opt module
parser module
scanner module
scannertest module
sortutil module
strutil module
token module
uint128 module
virtual module
xc module
y module

Jump to